modusa
======

``modusa`` is a Python library providing utility tools for research.

It offers purpose-built tools especially for the audio domain but not limited to. It combines **audio loading**, **annotation handling**, **visualization**, and **analysis** in a unified, easy-to-use API. It simplifies common workflows so you can focus on **experimentation and insight**, not boilerplate code.


.. toctree::
   :maxdepth: 1
   :caption: Quick Tour to Modusa
   
   How to use modusa? <https://meluron.github.io/devquest/htmls/Modusa-[C01]_-_A_Quick_Guide_on_Modusa.html>   
   

.. toctree::
   :maxdepth: 1
   :caption: API Reference
   
   loader
   visualizer
   synthesizer
   mediaplayer
   mediarecorder
   saver
   feature_extractor